pypi-check
==========

    Check for module name availability in PyPI using `pypilist`_

.. figure:: https://github.com/harshasrinivas/pypi-check/blob/master/pypi_check.png
   :alt: pypi-check

   pypi-check

Install
-------

::

    $ pip install pypi-check

Contribute
==========

If you want to add features, improve them, or report issues, feel free
to send a pull request.

License
=======

MIT © `Harsha Srinivas`_

.. _pypilist: https://github.com/harshasrinivas/pypilist
.. _Harsha Srinivas: https://harshasrinivas.me
